﻿/// バイト列の表現形式
/// 
/// ITweDataFormat で出力されるバイト列に対して、ヘッダフッタ等を付加したコマンド形態への変形を行う
/// 
/// 例えば以下のようなデータ Format, Payload で示されるされるデータがあった場合、
/// 78 01 00 11 22 33 44 55
/// ^^^^1 ^^^^^^^^^^^^^^^^2
/// Format            Payload
/// このバイト列に対しての表現形式を定義する。
/// 
/// 例えば clsDataPresentationAscii 形式では、以下のような文字列に表現される。
/// ":7801001122334455??[CR][LF]"
/// 
/// ?? はチェックサム
/// [CR][LF] は 0D 0A の改行コード
using System.Diagnostics;
using System.Linq;
using System.Collections.Generic;
using System.Collections;
using System;
using System.Xml.Linq;

namespace MONOW_PAL_PARSER
{
    public enum E_PARSE_STATE
    {
        EMPTY,
        READHEADER,
        READHEADER1,
        READHEADER2,
        READPAYLOAD,
        READPAYLOAD1,
        READPAYLOAD2,
        READLEN,
        READLEN1,
        READLEN2,
        READCHECKSUM,
        READCHECKSUM1,
        READCHECKSUM2,
        READFOTTER,
        READFOTTER1,
        READFOTTER2,
        COMPLETE,
        ERR
    }

    public interface ITweDataPresentation
    {
        /// <summary>
        /// 表現へのバイト列への変換
        /// </summary>
        /// <returns></returns>
        /// <remarks></remarks>
        byte[] toByteArray();

        /// <summary>
        /// １バイトを入力し、データを解釈する。
        /// 
        /// 空の ITweDataPresentation オブジェクトに対して、１バイトずつ解釈を進め、
        /// １系列として解釈を行うまで実行する。E_PARSE_STATE.COMPLETE になれば完了。
        /// 
        /// 完了後 ITweDataFormat オブジェクトが完成している。
        /// </summary>
        /// <param name="b"></param>
        /// <returns></returns>
        /// <remarks></remarks>
        E_PARSE_STATE ParseByte(byte b);

        /// <summary>
        /// ITweDataFormat 形式のオブジェクトを得る
        /// </summary>
        /// <value></value>
        /// <returns></returns>
        /// <remarks></remarks>
        ITweDataFormat ObjFormat { get; }

        /// <summary>
        /// データ解釈完了のタイムスタンプ
        /// </summary>
        /// <value></value>
        /// <returns></returns>
        /// <remarks></remarks>
        DateTime TimeGot { get; set; }
    }
}
